@@ -1,13 +1,12 @@
+#!/usr/bin/env python
 # -*- coding:utf-8 -*-
-# /usr/bin/env python
 """
-Date: 2021/5/4 15:58
-Desc: 交易所网站获取期货日线行情
+Date: 2021/11/25 17:23
+Desc: 期货日线行情
 """
 import datetime
 import json
 import re
-import warnings
 import zipfile
 from io import BytesIO, StringIO
 
@@ -21,30 +20,18 @@ from mssdk.futures.requests_fun import requests_link
 calendar = cons.get_calendar()
 
 
-def get_cffex_daily(date: str = "20100401") -> pd.DataFrame:
+def get_cffex_daily(date: str = "20100416") -> pd.DataFrame:
     """
-    中国金融期货交易所日交易数据
+    中国金融期货交易所-日频率交易数据
     http://www.cffex.com.cn/rtj/
-    :param date: 日期 format：YYYY-MM-DD 或 YYYYMMDD 或 datetime.date对象; 为空时为当天
-    :return: pandas.DataFrame
-    中国金融期货交易所日:
-    symbol        合约代码
-    date          日期
-    open          开盘价
-    high          最高价
-    low          最低价
-    close         收盘价
-    volume        成交量
-    open_interest   持仓量
-    turnover      成交额
-    settle        结算价
-    pre_settle    前结算价
-    variety       合约类别
-    或 None(给定日期没有交易数据)
+    :param date: 交易日; 数据开始时间为 20100416
+    :type date: str
+    :return: 日频率交易数据
+    :rtype: pandas.DataFrame
     """
     day = cons.convert_date(date) if date is not None else datetime.date.today()
     if day.strftime("%Y%m%d") not in calendar:
-        warnings.warn("%s非交易日" % day.strftime("%Y%m%d"))
+        # warnings.warn("%s非交易日" % day.strftime("%Y%m%d"))
         return None
     url = f"http://www.cffex.com.cn/sj/historysj/{date[:-2]}/zip/{date[:-2]}.zip"
     r = requests.get(url)
@@ -63,16 +50,58 @@ def get_cffex_daily(date: str = "20100401") -> pd.DataFrame:
     symbol_list = data_df["合约代码"].to_list()
     variety_list = [re.compile(r"[a-zA-Z_]+").findall(item)[0] for item in symbol_list]
     if data_df.shape[1] == 15:
-        data_df.columns = ["symbol", "open", "high", "low", "volume", "turnover",
-                           "open_interest", "_", "close", "settle", "pre_settle", "_", "_", "_", "_"]
+        data_df.columns = [
+            "symbol",
+            "open",
+            "high",
+            "low",
+            "volume",
+            "turnover",
+            "open_interest",
+            "_",
+            "close",
+            "settle",
+            "pre_settle",
+            "_",
+            "_",
+            "_",
+            "_",
+        ]
     else:
-        data_df.columns = ["symbol", "open", "high", "low", "volume", "turnover",
-                           "open_interest", "_", "close", "settle", "pre_settle", "_", "_", "_"]
+        data_df.columns = [
+            "symbol",
+            "open",
+            "high",
+            "low",
+            "volume",
+            "turnover",
+            "open_interest",
+            "_",
+            "close",
+            "settle",
+            "pre_settle",
+            "_",
+            "_",
+            "_",
+        ]
     data_df["date"] = date
     data_df["variety"] = variety_list
     data_df = data_df[
-        ["symbol", "date", "open", "high", "low", "close", "volume", "open_interest", "turnover", "settle",
-         "pre_settle", "variety"]]
+        [
+            "symbol",
+            "date",
+            "open",
+            "high",
+            "low",
+            "close",
+            "volume",
+            "open_interest",
+            "turnover",
+            "settle",
+            "pre_settle",
+            "variety",
+        ]
+    ]
     return data_df
 
 
@@ -89,7 +118,7 @@ def get_ine_daily(date: str = "20200106") -> pd.DataFrame:
     """
     day = cons.convert_date(date) if date is not None else datetime.date.today()
     if day.strftime("%Y%m%d") not in calendar:
-        warnings.warn(f"{day.strftime('%Y%m%d')}非交易日")
+        # warnings.warn(f"{day.strftime('%Y%m%d')}非交易日")
         return None
     url = f"http://www.ine.cn/data/dailydata/kx/kx{day.strftime('%Y%m%d')}.dat"
     r = requests.get(url)
@@ -102,9 +131,18 @@ def get_ine_daily(date: str = "20200106") -> pd.DataFrame:
     temp_df = temp_df[temp_df["DELIVERYMONTH"] != "小计"]
     temp_df = temp_df[~temp_df["PRODUCTNAME"].str.contains("总计")]
     try:
-        result_df["symbol"] = temp_df["PRODUCTGROUPID"].str.upper().str.strip() + temp_df["DELIVERYMONTH"]
+        result_df["symbol"] = (
+            temp_df["PRODUCTGROUPID"].str.upper().str.strip() + temp_df["DELIVERYMONTH"]
+        )
     except:
-        result_df["symbol"] = temp_df["PRODUCTID"].str.upper().str.strip().str.split("_", expand=True).iloc[:, 0] + temp_df["DELIVERYMONTH"]
+        result_df["symbol"] = (
+            temp_df["PRODUCTID"]
+            .str.upper()
+            .str.strip()
+            .str.split("_", expand=True)
+            .iloc[:, 0]
+            + temp_df["DELIVERYMONTH"]
+        )
     result_df["date"] = day.strftime("%Y%m%d")
     result_df["open"] = temp_df["OPENPRICE"]
     result_df["high"] = temp_df["HIGHESTPRICE"]
@@ -118,7 +156,13 @@ def get_ine_daily(date: str = "20200106") -> pd.DataFrame:
     try:
         result_df["variety"] = temp_df["PRODUCTGROUPID"].str.upper().str.strip()
     except:
-        result_df["variety"] = temp_df["PRODUCTID"].str.upper().str.strip().str.split("_", expand=True).iloc[:, 0]
+        result_df["variety"] = (
+            temp_df["PRODUCTID"]
+            .str.upper()
+            .str.strip()
+            .str.split("_", expand=True)
+            .iloc[:, 0]
+        )
     result_df = result_df[result_df["symbol"] != "总计"]
     result_df = result_df[~result_df["symbol"].str.contains("efp")]
     return result_df
@@ -134,20 +178,23 @@ def get_czce_daily(date: str = "20050525") -> pd.DataFrame:
     """
     day = cons.convert_date(date) if date is not None else datetime.date.today()
     if day.strftime("%Y%m%d") not in calendar:
-        warnings.warn(f"{day.strftime('%Y%m%d')}非交易日")
+        # warnings.warn(f"{day.strftime('%Y%m%d')}非交易日")
         return None
     if day > datetime.date(2010, 8, 24):
-        if day > datetime.date(2015, 9, 19):
+        if day > datetime.date(2015, 11, 11):
             u = cons.CZCE_DAILY_URL_3
             url = u % (day.strftime("%Y"), day.strftime("%Y%m%d"))
-        elif day < datetime.date(2015, 9, 19):
+        elif day <= datetime.date(2015, 11, 11):
             u = cons.CZCE_DAILY_URL_2
             url = u % (day.strftime("%Y"), day.strftime("%Y%m%d"))
         listed_columns = cons.CZCE_COLUMNS
         output_columns = cons.OUTPUT_COLUMNS
         try:
             r = requests.get(url)
-            html = r.text
+            if datetime.date(2015, 11, 12) <= day <= datetime.date(2017, 12, 27):
+                html = str(r.content, encoding="gbk")
+            else:
+                html = r.text
         except requests.exceptions.HTTPError as reason:
             if reason.response.status_code != 404:
                 print(
@@ -155,16 +202,16 @@ def get_czce_daily(date: str = "20050525") -> pd.DataFrame:
                     % (day.strftime("%Y"), day.strftime("%Y%m%d")),
                     reason,
                 )
-            return
+            return None
         if html.find("您的访问出错了") >= 0 or html.find("无期权每日行情交易记录") >= 0:
-            return
+            return None
         html = [
             i.replace(" ", "").split("|")
             for i in html.split("\n")[:-4]
             if i[0][0] != "小"
         ]
 
-        if day > datetime.date(2015, 9, 19):
+        if day > datetime.date(2015, 11, 11):
             if html[1][0] not in ["品种月份", "品种代码", "合约代码"]:
                 return
             dict_data = list()
@@ -175,7 +222,7 @@ def get_czce_daily(date: str = "20050525") -> pd.DataFrame:
                     continue
                 row_dict = {"date": day_const, "symbol": row[0], "variety": m.group(1)}
                 for i, field in enumerate(listed_columns):
-                    if row[i + 1] == "\r" or row[i + 1] == '':
+                    if row[i + 1] == "\r" or row[i + 1] == "":
                         row_dict[field] = 0.0
                     elif field in [
                         "volume",
@@ -191,7 +238,7 @@ def get_czce_daily(date: str = "20050525") -> pd.DataFrame:
                 dict_data.append(row_dict)
 
             return pd.DataFrame(dict_data)[output_columns]
-        elif day < datetime.date(2015, 9, 19):
+        elif day <= datetime.date(2015, 11, 11):
             dict_data = list()
             day_const = int(day.strftime("%Y%m%d"))
             for row in html[1:]:
@@ -242,7 +289,7 @@ def get_czce_daily(date: str = "20050525") -> pd.DataFrame:
 
 def get_shfe_v_wap(date: str = "20131017") -> pd.DataFrame:
     """
-    获取上期所日成交均价数据
+    上期所日成交均价数据
     Parameters
     ------
     date: 日期 format：YYYY-MM-DD 或 YYYYMMDD 或 datetime.date对象 为空时为当天
@@ -258,7 +305,7 @@ def get_shfe_v_wap(date: str = "20131017") -> pd.DataFrame:
     """
     day = cons.convert_date(date) if date is not None else datetime.date.today()
     if day.strftime("%Y%m%d") not in calendar:
-        warnings.warn("%s非交易日" % day.strftime("%Y%m%d"))
+        # warnings.warn("%s非交易日" % day.strftime("%Y%m%d"))
         return None
     try:
         json_data = json.loads(
@@ -309,7 +356,7 @@ def get_shfe_daily(date: str = "20160104") -> pd.DataFrame:
     """
     day = cons.convert_date(date) if date is not None else datetime.date.today()
     if day.strftime("%Y%m%d") not in calendar:
-        warnings.warn("%s非交易日" % day.strftime("%Y%m%d"))
+        # warnings.warn("%s非交易日" % day.strftime("%Y%m%d"))
         return None
     try:
         json_data = json.loads(
@@ -336,7 +383,13 @@ def get_shfe_daily(date: str = "20160104") -> pd.DataFrame:
     try:
         df["variety"] = df["PRODUCTGROUPID"].str.upper().str.strip()
     except KeyError as e:
-        df["variety"] = df["PRODUCTID"].str.upper().str.split('_', expand=True).iloc[:, 0].str.strip()
+        df["variety"] = (
+            df["PRODUCTID"]
+            .str.upper()
+            .str.split("_", expand=True)
+            .iloc[:, 0]
+            .str.strip()
+        )
     df["symbol"] = df["variety"] + df["DELIVERYMONTH"]
     df["date"] = day.strftime("%Y%m%d")
     v_wap_df = get_shfe_v_wap(day)
@@ -367,7 +420,7 @@ def get_dce_daily(date: str = "20030115") -> pd.DataFrame:
     """
     day = cons.convert_date(date) if date is not None else datetime.date.today()
     if day.strftime("%Y%m%d") not in calendar:
-        warnings.warn("%s非交易日" % day.strftime("%Y%m%d"))
+        # warnings.warn("%s非交易日" % day.strftime("%Y%m%d"))
         return None
     url = "http://www.dce.com.cn/publicweb/quotesdata/exportDayQuotesChData.html"
     headers = {
@@ -401,28 +454,62 @@ def get_dce_daily(date: str = "20030115") -> pd.DataFrame:
     data_df["symbol"] = data_df["variety"] + data_df["交割月份"].astype(int).astype(str)
     del data_df["商品名称"]
     del data_df["交割月份"]
-    data_df.columns = ["open", "high", "low", "close",
-                       "pre_settle", "settle", "_", "_",
-                       "volume", "open_interest", "_", "turnover", "variety", "symbol"]
+    data_df.columns = [
+        "open",
+        "high",
+        "low",
+        "close",
+        "pre_settle",
+        "settle",
+        "_",
+        "_",
+        "volume",
+        "open_interest",
+        "_",
+        "turnover",
+        "variety",
+        "symbol",
+    ]
     data_df["date"] = date
     data_df = data_df[
-        ["symbol", "date", "open", "high", "low", "close", "volume", "open_interest", "turnover", "settle",
-         "pre_settle", "variety"]]
+        [
+            "symbol",
+            "date",
+            "open",
+            "high",
+            "low",
+            "close",
+            "volume",
+            "open_interest",
+            "turnover",
+            "settle",
+            "pre_settle",
+            "variety",
+        ]
+    ]
     data_df = data_df.applymap(lambda x: x.replace(",", ""))
-    data_df = data_df.astype({"open": "float",
-                              "high": "float",
-                              "low": "float",
-                              "close": "float",
-                              "volume": "float",
-                              "open_interest": "float",
-                              "turnover": "float",
-                              "settle": "float",
-                              "pre_settle": "float",
-                              })
+    data_df = data_df.astype(
+        {
+            "open": "float",
+            "high": "float",
+            "low": "float",
+            "close": "float",
+            "volume": "float",
+            "open_interest": "float",
+            "turnover": "float",
+            "settle": "float",
+            "pre_settle": "float",
+        }
+    )
     return data_df
 
 
-def get_futures_daily(start_date: str = "20210421", end_date: str = "20210426", market: str = "INE", index_bar: bool = False) -> pd.DataFrame:
+def get_futures_daily(
+    start_date: str = "20201031",
+    end_date: str = "20201031",
+    market: str = "CZCE",
+    index_bar: bool = False,
+) -> pd.DataFrame:
     """
     交易所日交易数据
     :param start_date: 开始日期 format：YYYY-MM-DD 或 YYYYMMDD 或 datetime.date对象 为空时为当天
@@ -451,7 +538,9 @@ def get_futures_daily(start_date: str = "20210421", end_date: str = "20210426",
         return None
 
     start_date = (
-        cons.convert_date(start_date) if start_date is not None else datetime.date.today()
+        cons.convert_date(start_date)
+        if start_date is not None
+        else datetime.date.today()
     )
     end_date = (
         cons.convert_date(end_date)
@@ -470,7 +559,7 @@ def get_futures_daily(start_date: str = "20210421", end_date: str = "20210426",
 
     if len(df_list) > 0:
         temp_df = pd.concat(df_list).reset_index(drop=True)
-        temp_df = temp_df[~temp_df['symbol'].str.contains("efp")]
+        temp_df = temp_df[~temp_df["symbol"].str.contains("efp")]
         return temp_df
 
 
@@ -496,12 +585,15 @@ def get_futures_index(df: pd.DataFrame) -> pd.DataFrame:
             if "efp" in df_cut.iloc[-1, 0]:
                 df_cut = df_cut.iloc[:-1, :]
             df_cut.replace("", 0, inplace=True)  # 20201026 部分数据开盘价空缺
-            index_df[["open", "high", "low", "close", "settle", "pre_settle"]] = np.dot(
-                np.array(
-                    df_cut[["open", "high", "low", "close", "settle", "pre_settle"]]
-                ).T,
-                np.array((df_cut["open_interest"].astype(float))),
-            ) / np.sum(df_cut["open_interest"].astype(float))
+            index_df[["open", "high", "low", "close", "settle", "pre_settle"]] = (
+                np.dot(
+                    np.array(
+                        df_cut[["open", "high", "low", "close", "settle", "pre_settle"]]
+                    ).T,
+                    np.array((df_cut["open_interest"].astype(float))),
+                )
+                / np.sum(df_cut["open_interest"].astype(float))
+            )
             index_df[["date", "variety"]] = df_cut[["date", "variety"]].iloc[0, :]
             index_df["symbol"] = index_df["variety"] + "99"
             index_dfs.append(index_df)
@@ -509,19 +601,21 @@ def get_futures_index(df: pd.DataFrame) -> pd.DataFrame:
 
 
 if __name__ == "__main__":
-    get_futures_daily_df = get_futures_daily(start_date='20200105', end_date='20200201', market="INE", index_bar=False)
+    get_futures_daily_df = get_futures_daily(
+        start_date="20200105", end_date="20200201", market="INE", index_bar=False
+    )
     print(get_futures_daily_df)
 
     get_dce_daily_df = get_dce_daily(date="20210427")
     print(get_dce_daily_df)
 
-    get_cffex_daily_df = get_cffex_daily(date="20101101")
+    get_cffex_daily_df = get_cffex_daily(date="20210719")
     print(get_cffex_daily_df)
 
     get_ine_daily_df = get_ine_daily(date="20210426")
     print(get_ine_daily_df)
 
-    get_czce_daily_df = get_czce_daily(date="20210416")
+    get_czce_daily_df = get_czce_daily(date="20151111")
     print(get_czce_daily_df)
 
     get_shfe_daily_df = get_shfe_daily(date="20160104")
